@@ -45,34 +45,30 @@ class IMAPFolder(BaseFolder):
 
     def getuidvalidity(self):
         imapobj = self.imapserver.acquireconnection()
+        x = None
+        readonlysave = imapobj.is_readonly
+        imapobj.is_readonly = 1
         try:
-            try:
-                x = imapobj.status(self.getfullname(), '(UIDVALIDITY)')[1][0]
-            except imapobj.readonly:
-                pass
+            x = imapobj.status(self.getfullname(), '(UIDVALIDITY)')[1][0]
         finally:
             self.imapserver.releaseconnection(imapobj)
+            imapobj.is_readonly = readonlysave
         uidstring = imaputil.imapsplit(x)[1]
         return long(imaputil.flagsplit(uidstring)[1])
     
     def cachemessagelist(self):
         imapobj = self.imapserver.acquireconnection()
         try:
-            try:
-                imapobj.select(self.getfullname()) # Needed for fetch below
-            except imapobj.readonly:
-                pass
             self.messagelist = {}
-            try:
-                response = imapobj.status(self.getfullname(), '(MESSAGES)')[1][0]
-            except imapobj.readonly:
-                pass
+            response = imapobj.status(self.getfullname(), '(MESSAGES)')[1][0]
             result = imaputil.imapsplit(response)[1]
             maxmsgid = long(imaputil.flags2hash(result)['MESSAGES'])
             if (maxmsgid < 1):
                 # No messages?  return.
                 return
 
+            # Needed for fetch below
+            imapobj.select(self.getfullname(), readonly = 1)
             # Now, get the flags and UIDs for these.
             response = imapobj.fetch('1:%d' % maxmsgid, '(FLAGS UID)')[1]
         finally:
@@ -91,10 +87,7 @@ class IMAPFolder(BaseFolder):
     def getmessage(self, uid):
         imapobj = self.imapserver.acquireconnection()
         try:
-            try:
-                imapobj.select(self.getfullname())
-            except imapobj.readonly:
-                pass
+            imapobj.select(self.getfullname(), readonly = 1)
             return imapobj.uid('fetch', '%d' % uid, '(BODY.PEEK[])')[1][0][1].replace("\r\n", "\n")
         finally:
             self.imapserver.releaseconnection(imapobj)
